==> keyclic_sdk_api-1.39.1.tar.gz: lib/model/choice.dart <==
part of keyclic_sdk_api.api;

class Choice {
  String type = null;

  List<String> enum_ = [];

  String description = null;

  String format = null;

  int maxItems = null;

  int minItems = null;

  String default_ = null;

  int propertyOrder = null;

  String title = null;

  Choice({
    this.type,
    this.enum_,
    this.description,
    this.format,
    this.maxItems,
    this.minItems,
    this.default_,
    this.propertyOrder,
    this.title,
  });

  @override
  String toString() {
    return 'Choice[type=$type, enum_=$enum_, description=$description, format=$format, maxItems=$maxItems, minItems=$minItems, default_=$default_, propertyOrder=$propertyOrder, title=$title, ]';
  }

  Choice.fromJson(Map<String, dynamic> json) {
    if (json == null) return;
    type = json['type'];
    enum_ = (json['enum'] as List)?.map((item) => item as String)?.toList();
    description = json['description'];
    format = json['format'];
    maxItems = json['maxItems'];
    minItems = json['minItems'];
    default_ = json['default'];
    propertyOrder = json['propertyOrder'];
    title = json['title'];
  }

  Map<String, dynamic> toJson() {
    return {
      'type': type,
      'enum': enum_,
      'description': description,
      'format': format,
      'maxItems': maxItems,
      'minItems': minItems,
      'default': default_,
      'propertyOrder': propertyOrder,
      'title': title,
    };
  }

  static List<Choice> listFromJson(List<dynamic> json) {
    return json == null
        ? new List<Choice>()
        : json.map((value) => new Choice.fromJson(value)).toList();
  }

  static Map<String, Choice> mapFromJson(Map<String, dynamic> json) {
    var map = new Map<String, Choice>();
    if (json != null && json.length > 0) {
      json.forEach(
          (String key, dynamic value) => map[key] = new Choice.fromJson(value));
    }
    return map;
  }
}

==> keyclic_sdk_api-1.39.3.tar.gz: lib/model/choice.dart <==
part of keyclic_sdk_api.api;

class Choice {
  Choice();

  Choice.fromJson(Map<String, dynamic> json) {
    if (json == null) {
      return;
    }
    type = json['type'];
    enum_ = (json['enum'] as List)?.map((item) => item as String)?.toList();
    description = json['description'];
    format = json['format'];
    maxItems = json['maxItems'];
    minItems = json['minItems'];
    default_ = json['default'];
    propertyOrder = json['propertyOrder'];
    title = json['title'];
  }

  String type;

  List<String> enum_;

  String description;

  String format;

  int maxItems;

  int minItems;

  String default_;

  int propertyOrder;

  String title;

  Map<String, dynamic> toJson() {
    return {
      'type': type,
      'enum': enum_,
      'description': description,
      'format': format,
      'maxItems': maxItems,
      'minItems': minItems,
      'default': default_,
      'propertyOrder': propertyOrder,
      'title': title,
    };
  }

  @override
  String toString() {
    return 'Choice[type=$type, enum_=$enum_, description=$description, format=$format, maxItems=$maxItems, minItems=$minItems, default_=$default_, propertyOrder=$propertyOrder, title=$title, ]';
  }

  static List<Choice> listFromJson(List<dynamic> json) {
    return json == null ? List<Choice>() : json.map((value) => Choice.fromJson(value)).toList();
  }

  static Map<String, Choice> mapFromJson(Map<String, dynamic> json) {
    var map = Map<String, Choice>();
    if (json != null && json.isNotEmpty) {
      json.forEach((String key, dynamic value) => map[key] = Choice.fromJson(value));
    }
    return map;
  }
}
